#
# Copyright (c) 2008-2015 Thierry Florac <tflorac AT ulthar.net>
# All Rights Reserved.
#
# This software is subject to the provisions of the Zope Public License,
# Version 2.1 (ZPL).  A copy of the ZPL should accompany this distribution.
# THIS SOFTWARE IS PROVIDED "AS IS" AND ANY AND ALL EXPRESS OR IMPLIED
# WARRANTIES ARE DISCLAIMED, INCLUDING, BUT NOT LIMITED TO, THE IMPLIED
# WARRANTIES OF TITLE, MERCHANTABILITY, AGAINST INFRINGEMENT, AND FITNESS
# FOR A PARTICULAR PURPOSE.
#

__docformat__ = 'restructuredtext'


# import standard library

# import interfaces
from pyams_security.interfaces import ISecurityManager
from pyams_security.interfaces.notification import INotificationSettings

# import packages
from persistent import Persistent
from pyams_utils.adapter import adapter_config, get_annotation_adapter
from zope.interface import implementer
from zope.schema.fieldproperty import FieldProperty


@implementer(INotificationSettings)
class NotificationSettings(Persistent):
    """Notification settings"""

    enable_notifications = FieldProperty(INotificationSettings['enable_notifications'])
    mailer = FieldProperty(INotificationSettings['mailer'])
    service_name = FieldProperty(INotificationSettings['service_name'])
    service_owner = FieldProperty(INotificationSettings['service_owner'])
    sender_name = FieldProperty(INotificationSettings['sender_name'])
    sender_email = FieldProperty(INotificationSettings['sender_email'])
    subject_prefix = FieldProperty(INotificationSettings['subject_prefix'])
    signature = FieldProperty(INotificationSettings['signature'])


NOTIFICATIONS_KEY = 'pyams_security.notifications'


@adapter_config(context=ISecurityManager, provides=INotificationSettings)
def security_notification_settings_factory(context):
    """Security manager notifications factory adapter"""
    return get_annotation_adapter(context, NOTIFICATIONS_KEY, NotificationSettings, locate=False)
